==> vue-layout-builder-0.0.15.tgz: package/tests/unit/store/actions.spec.js <==
import cloneDeep from "clone-deep";
import actions from "../../../src/store/actions";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const store = Store(state);

describe("actions", () => {
  const data = {
    foo: "bar"
  };
  const stub = jest.fn();
  store.commit = stub;

  afterEach(() => {
    store.replaceState(cloneDeep(state));
  });

  describe("editContent()", () => {
    it("commits editContent on the store", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("editContent", data);
    });

    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setIframeSrc on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setIframeSrc", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("showContentTypesOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with data", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", data);
    });

    it("commits setContentTypesOverlayVisibility on the store with true", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        true
      );
    });
  });

  describe("closeElementsOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("showIframe()", () => {
    const params = {
      indexSection: 1,
      indexSectionBlock: 0,
      slotId: "1"
    };

    it("commits setCurrentlyEditableContent on the store with the given data", () => {
      actions.showIframe(store, params);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", params);
    });

    it("commits setIframeSrc on the store with the correct editUrl", () => {
      actions.showIframe(store, params);
      expect(stub).toHaveBeenCalledWith(
        "setIframeSrc",
        store.state.elements[
          store.state.sections[params.indexSection].content[params.slotId][
            params.indexSectionBlock
          ]
        ].editUrl
      );
    });
  });
});

==> vue-layout-builder-0.0.16.tgz: package/tests/unit/store/actions.spec.js <==
import cloneDeep from "clone-deep";
import actions from "../../../src/store/actions";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const store = Store(state);

describe("actions", () => {
  const data = {
    id: "element1"
  };
  const stub = jest.fn();
  store.commit = stub;

  afterEach(() => {
    store.replaceState(cloneDeep(state));
  });

  describe("editContent()", () => {
    describe("when the passed element doesn't exit in the state yet", () => {
      it("commits addElement with the past data to the store", () => {
        actions.editContent(store, data);
        expect(stub).toHaveBeenCalledWith("addElement", data);
      });
    });

    describe("when the passed element exists in the state", () => {
      it("doesn't commit addElement to the store", () => {
        const props = {
          id: "element7"
        };
        actions.editContent(store, props);
        expect(stub).not.toHaveBeenCalledWith("addElement", props);
      });
    });

    it("commits editContent on the store", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("editContent", data);
    });

    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("showContentTypesOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with data", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", data);
    });

    it("commits setContentTypesOverlayVisibility on the store with true", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        true
      );
    });
  });

  describe("closeElementsOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("editElement()", () => {
    const params = {
      indexSection: 1,
      indexSectionBlock: 0,
      slotId: "1"
    };
    const stub2 = jest.fn();
    store.state.adapters.callbacks.editContentInstance = stub2;

    it("commits setCurrentlyEditableContent on the store with the given data", () => {
      actions.editElement(store, params);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", params);
    });

    it("calls this.$store.state.adapters.callbacks.editContentInstance() with the given url", () => {
      actions.editElement(store, params);
      expect(stub2).toHaveBeenCalledWith(
        store.state.elements[
          store.state.sections[params.indexSection].content[params.slotId][
            params.indexSectionBlock
          ]
        ].editUrl
      );
    });
  });
});
